@@ -25,9 +25,9 @@ operations on the Accessible object, such as invoking default actions or
 moving the text caret.
 """
 
-__id__        = "$Id: braille.py 4171 2008-09-08 04:20:48Z joanied $"
-__version__   = "$Revision: 4171 $"
-__date__      = "$Date: 2008-09-08 00:20:48 -0400 (Mon, 08 Sep 2008) $"
+__id__        = "$Id: braille.py 4273 2008-10-03 17:35:13Z joanied $"
+__version__   = "$Revision: 4273 $"
+__date__      = "$Date: 2008-10-03 13:35:13 -0400 (Fri, 03 Oct 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -455,6 +455,32 @@ class Component(Region):
         else:
             action.doAction(0)
 
+class Link(Component):
+    """A subclass of Component backed by an accessible.  This Region will be
+    marked as a link by dots 7 or 8, depending on the user's preferences.
+    """
+
+    def __init__(self, accessible, string, cursorOffset=0):
+        """Initialize a Link region. similar to Component, but here we always
+        have the region expand on cursor."""
+        Component.__init__(self, accessible, string, cursorOffset, '', True)
+
+    def getAttributeMask(self, getLinkMask=True):
+        """Creates a string which can be used as the attrOr field of brltty's
+        write structure for the purpose of indicating text attributes and
+        selection.
+        Arguments:
+
+        - getLinkMask: Whether or not we should take the time to get
+          the attributeMask for links. Reasons we might not want to
+          include knowning that we will fail and/or it taking an
+          unreasonable amount of time (AKA Gecko).
+        """
+
+        # Create an link indicator mask.
+        #
+        return chr(settings.brailleLinkIndicator) * len(self.string)
+
 class Text(Region):
     """A subclass of Region backed by a Text object.  This Region will
     react to any cursor routing key events by positioning the caret in
@@ -475,7 +501,8 @@ class Text(Region):
         self.accessible = accessible
         if orca_state.activeScript:
             [string, self.caretOffset, self.lineOffset] = \
-                 orca_state.activeScript.getTextLineAtCaret(self.accessible)
+                 orca_state.activeScript.getTextLineAtCaret(self.accessible,
+                                                            startOffset)
         else:
             string = ""
 
@@ -527,7 +554,8 @@ class Text(Region):
         """
 
         [string, caretOffset, lineOffset] = \
-                 orca_state.activeScript.getTextLineAtCaret(self.accessible)
+                 orca_state.activeScript.getTextLineAtCaret(self.accessible,
+                                                            self.startOffset)
         string = string.decode("UTF-8")
 
         cursorOffset = min(caretOffset - lineOffset, len(string))
@@ -653,7 +681,7 @@ class Text(Region):
                     contractedMask[outPos[i]] |= m
                 except IndexError:
                     continue
-            regionMask = contractedMask
+            regionMask = contractedMask[:len(self.string)]
 
         # Add empty mask characters for the EOL character as well as for
         # any label that might be present.
