@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 4044 2008-07-18 12:45:13Z wwalker $"
-__version__   = "$Revision: 4044 $"
-__date__      = "$Date: 2008-07-18 08:45:13 -0400 (Fri, 18 Jul 2008) $"
+__id__        = "$Id: settings.py 4279 2008-10-07 22:40:23Z joanied $"
+__version__   = "$Revision: 4279 $"
+__date__      = "$Date: 2008-10-07 18:40:23 -0400 (Tue, 07 Oct 2008) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -107,7 +107,9 @@ userCustomizableSettings = [
     "enableFunctionKeys",
     "enableActionKeys",
     "enableNavigationKeys",
+    "enableTutorialMessages",
     "enableBraille",
+    "enableBrailleContext",
     "enableBrailleGrouping",
     "disableBrailleEOL",
     "brailleEOLIndicator",
@@ -295,6 +297,13 @@ httpServerPort          = 0
 #
 maxHttpServerRetries    = 20
 
+# Whether or not to use DBUS.
+#
+if os.getenv("DBUS_SESSION_BUS_ADDRESS"):
+    useDBus = True
+else:
+    useDBus = False
+
 # Whether or not recording is enabled via the HTTP server. 
 #
 enableRemoteLogging     = False
@@ -335,6 +344,12 @@ enableSpeechIndentation = False
 #
 enableBraille           = True
 
+# If True, add the hierarchical context of an object to the braille
+# line.  People with very large braille displays may want to set this
+# to False.
+#
+enableBrailleContext    = True
+
 # If True, enable the grouping of children on the braille display.
 # This is for things like displaying all items of a menu, tab list,
 # menu bar, etc., on a single line of the braille display.
@@ -562,6 +577,9 @@ enableActionKeys        = True
 #
 enableNavigationKeys    = False
 
+# If True, roles that have tutorial strings defined will be spoken.
+enableTutorialMessages = False
+
 # If True, show the main Orca window.
 #
 showMainWindow          = True
@@ -581,6 +599,29 @@ GENERAL_KEYBOARD_LAYOUT_DESKTOP = 1
 GENERAL_KEYBOARD_LAYOUT_LAPTOP  = 2
 keyboardLayout                  = GENERAL_KEYBOARD_LAYOUT_DESKTOP
 
+# The red, green, blue values to use to outline the current item in
+# flat review mode. They are values between 0 and 65535 (0xFFFF), with
+# 65535 (0xFFFF) indicating full intensitiy
+#
+outlineColor = [ 0xFFFF, 0x0000, 0x0000 ]
+
+# Thickness in pixels of the outline around the the current item in flat 
+# review mode.
+#
+outlineThickness = 4
+
+# Margin between the object being outlined and the actual outline
+#
+outlineMargin = 1
+
+# The kind of outlining to do for flat review mode.
+#
+OUTLINE_NONE = 0
+OUTLINE_BOX = 1
+OUTLINE_LINE = 2
+OUTLINE_WEDGES = 3
+outlineStyle = OUTLINE_BOX
+
 # If True, speak blank lines.
 #
 speakBlankLines         = True
@@ -592,7 +633,7 @@ readTableCellRow    = True
 
 # If True, enable speaking of progress bar updates.
 #
-enableProgressBarUpdates = False
+enableProgressBarUpdates = True
 
 # The interval (in seconds) between speaking progress bar updates. A value
 # of zero means that progress bar updates should not be spoken at all.
@@ -806,10 +847,12 @@ def setAccessibilityEnabled(enable):
 def isOrcaAutostarted():
     """Return an indication of whether Orca autostart at login time is enabled.
     """
-
-    userDesktopFile = os.path.join(os.environ["HOME"], ".config", \
-                                   "autostart", "orca.desktop")
-    return os.path.exists(userDesktopFile)
+    prefix = "/desktop/gnome/applications/at/visual/"
+    try:
+	return ("orca" in gconfClient.get_string(prefix + "exec")) \
+           and gconfClient.get_bool(prefix + "startup")
+    except:
+        return False
 
 def setOrcaAutostart(enable):
     """Enable or disable the autostart of Orca at login time.
@@ -819,34 +862,12 @@ def setOrcaAutostart(enable):
 
     Returns an indication of whether the operation was successful.
     """
-
-    status = True
-    systemDesktopFile = os.path.join(platform.prefix, platform.datadirname, \
-                                     "applications", "orca.desktop")
-    autostartDir = os.path.join(os.environ["HOME"], ".config", "autostart")
-    userDesktopFile = os.path.join(os.environ["HOME"], ".config", \
-                                   "autostart", "orca.desktop")
-
+    prefix = "/desktop/gnome/applications/at/visual/"
     try:
-        # If the user wants to enable Orca autostart, then copy the
-        # orca.desktop file from /usr/share/applications to
-        # ~/.config/autostart directory (creating the autostart directory
-        # if neccessary).
-        #
-        # If the user wants to disable this feature, then just remove 
-        # ~/.config/autostart/orca.desktop (if it exists).
-        #
-        if enable:
-            try:
-                os.chdir(autostartDir)
-            except:
-                os.mkdir(autostartDir)
-            shutil.copy(systemDesktopFile, userDesktopFile)
-        else:
-            os.remove(userDesktopFile)
+        return gconfClient.set_string(prefix + "exec", "orca") \
+           and gconfClient.set_bool(prefix + "startup", enable)
     except:
-        status = False
-    return status
+        return False
 
 # Obtain/set information regarding whether the gksu keyboard grab is enabled
 # or not.
@@ -964,11 +985,6 @@ setScriptMapping(re.compile(_('soffice')), "soffice")
 #
 setScriptMapping(re.compile(_('[Ee]volution')), "evolution")
 
-# Translators: see the regular expression note above.  This is for the
-# help application (yelp).
-#
-setScriptMapping(re.compile(_('yelp')), "Mozilla")
-
 # Translators: see the regular expression note above.  This is for a
 # version of Mozilla Firefox, which chooses to create strange names
 # for itself at the drop of a hat.
@@ -987,6 +1003,11 @@ setScriptMapping(re.compile(_('Bon Echo')), "Mozilla")
 #
 setScriptMapping(re.compile(_('Minefield')), "Mozilla")
 
+# This is a temporary fix for the schema/FF 3.0 not being accessible
+# issue. (See GNOME bugs #535827 and #555466.)
+#
+setScriptMapping(re.compile('[Ff]irefox'), "Mozilla")
+
 # Translators: see the regular expression note above.  This is for a
 # version of Thunderbird, which chooses to now call itself by a different
 # name.
@@ -1013,6 +1034,16 @@ setScriptMapping(re.compile(_('vte')), "gnome-terminal")
 #
 setScriptMapping(re.compile(_('gaim')), "pidgin")
 
+# Translators: see the regular expression note above.  This is for
+# supporting yelp, which sometimes identifies itself as gnome-help.
+# [[[TODO - JD: Not marked for translation due to string freeze,
+# plus gnome-help doesn't translate its app name as far as we can
+# determine.  So, translating this string really seems like extra
+# busy work for our translators.]]]
+#
+#setScriptMapping(re.compile(_('gnome-help')), "yelp")
+setScriptMapping(re.compile('gnome-help'), "yelp")
+
 # Show deprecated messeges in debug output.
 # Set this to True to help find potential pyatspi porting problems
 #
